@@ -1,29 +1,52 @@
 '''
 PyMT: multitouch toolkit
 
-PyMT is a python module for developing multi-touch enabled media rich applications.
+PyMT is an open source library for developing multi-touch applications. It is
+completely cross platform (Linux/OSX/Win) and released under the terms of the
+GNU LGPL.
 
-Currently the aim is to allow for quick and easy interaction design and rapid prototype development. There is also a focus on logging tasks or sessions of user interaction to quantitative data and the analysis/visualization of such data.
+It comes with native support for many multi-touch input devices, a growing
+library of multi-touch aware widgets, hardware accelerated OpenGL drawing,
+and an architecture that is designed to let you focus on building custom and
+highly interactive applications as quickly and easily as possible.
 
-You can visit http://pymt.txzone.net/ for more informations !
+Since PyMT is a pure Python library, you can take advantage of its highly
+dynamic nature and use any of the thousands of high quality and open source
+python libraries out there.
+
+You can visit http://pymt.eu/ for more informations !
 '''
 
-__version__ = '0.4'
+__version__ = '0.5'
 
 import sys
 import getopt
 import os
-from logger import pymt_logger, LOG_LEVELS
-import logger
+from pymt.logger import pymt_logger, LOG_LEVELS
 
-# Version number of current configuration format
-PYMT_CONFIG_VERSION = 8
+# internals for post-configuration
+__pymt_post_configuration = []
+def pymt_configure():
+    '''Call post-configuration of PyMT.
+    This function must be called in case of you create yourself the window.
+    '''
+    for callback in __pymt_post_configuration:
+        callback()
+
+def pymt_register_post_configuration(callback):
+    '''Register a function to be call when pymt_configure() will be called.
+
+    .. warning::
+        Internal use only.
+    '''
+    __pymt_post_configuration.append(callback)
 
 # Start !
 pymt_logger.info('PyMT v%s' % (__version__))
 
 # Global settings options for pymt
 options = {
+    'use_accelerate': True,
     'shadow_window': True,
     'window': ('pygame', 'glut'),
     'text': ('pil', 'cairo', 'pygame'),
@@ -31,6 +54,8 @@ options = {
     'audio': ('pygame', 'gstreamer', ),
     'image': ('pil', 'pygame'),
     'camera': ('opencv', 'gstreamer', 'videocapture'),
+    'svg': ('squirtle',),
+    'spelling': ('enchant', 'osxappkit',),
 }
 
 # Read environment
@@ -43,8 +68,9 @@ for option in options:
             else:
                 options[option] = os.environ[key].lower() in \
                     ('true', '1', 'yes', 'yup')
-        except:
-            pymt_logger.warning('Core: Wrong value for %s environment key' % key)
+        except Exception:
+            pymt_logger.warning('Core: Wrong value for %s'
+                                'environment key' % key)
             pymt_logger.exception('')
 
 # Extract all needed path in pymt
@@ -58,6 +84,8 @@ pymt_modules_dir     = os.path.join(pymt_base_dir, 'modules')
 pymt_data_dir        = os.path.join(pymt_base_dir, 'data')
 #: PyMT input provider directory
 pymt_providers_dir   = os.path.join(pymt_base_dir, 'input', 'providers')
+#: PyMT icons config path (don't remove last '')
+pymt_icons_dir        = os.path.join(pymt_data_dir, 'icons', '')
 #: PyMT user-home storage directory
 pymt_home_dir        = None
 #: PyMT configuration filename
@@ -85,14 +113,14 @@ if not 'PYMT_DOC_INCLUDE' in os.environ:
         os.mkdir(pymt_usermodules_dir)
 
     # configuration
-    from config import *
+    from pymt.config import *
 
     # Set level of logger
     level = LOG_LEVELS.get(pymt_config.get('pymt', 'log_level'))
     pymt_logger.setLevel(level=level)
-    
-    #Disable pyOpenGL auto GL Error Check?
-    gl_check = pymt_config.get('pymt', 'gl_error_check') 
+
+    # Disable pyOpenGL auto GL Error Check?
+    gl_check = pymt_config.get('pymt', 'gl_error_check')
     if gl_check.lower() in ['0', 'false', 'no']:
         import OpenGL
         OpenGL.ERROR_CHECKING = False
@@ -104,35 +132,40 @@ if not 'PYMT_DOC_INCLUDE' in os.environ:
     # Note: import are done after logger module initialization,
     # and configuration applied to logger.
 
+    # first, compile & use accelerate module
+    from pymt.accelerate import *
+
     # no dependices at all
-    from baseobject import *
-    from exceptions import *
-    from cache import Cache
+    from pymt.baseobject import *
+    from pymt.exceptions import *
+    from pymt.resources import *
+    from pymt.cache import Cache
 
     # system dependices
-    from utils import *
-    from event import *
-    from clock import *
-    from texture import *
-    from plugin import *
+    from pymt.utils import *
+    from pymt.event import *
+    from pymt.clock import *
+    from pymt.texture import *
+    from pymt.plugin import *
 
     # internal dependices
-    from graphx import *
-    from vector import *
+    from pymt.graphx import *
+    from pymt.vector import *
+    from pymt.geometry import *
 
     # dependices
-    from core import *
-    from modules import *
-    from input import *
-    from base import *
+    from pymt.core import *
+    from pymt.modules import *
+    from pymt.input import *
+    from pymt.base import *
 
     # after dependices
-    from gesture import *
-    from obj import OBJ
-    from loader import *
+    from pymt.gesture import *
+    from pymt.obj import OBJ
+    from pymt.loader import *
 
     # widgets
-    from ui import *
+    from pymt.ui import *
 
     # Can be overrided in command line
     try:
@@ -150,8 +183,8 @@ if not 'PYMT_DOC_INCLUDE' in os.environ:
                 pymt_usage()
                 sys.exit(0)
             elif opt in ('-p', '--provider'):
-                id, args = arg.split(':', 1)
-                pymt_config.set('input', id, args)
+                pid, args = arg.split(':', 1)
+                pymt_config.set('input', pid, args)
             elif opt in ('-a', '--auto-fullscreen'):
                 pymt_config.set('graphics', 'fullscreen', 'auto')
             elif opt in ('-k', '--fake-fullscreen'):
@@ -188,7 +221,8 @@ if not 'PYMT_DOC_INCLUDE' in os.environ:
                 with open(pymt_config_fn, 'w') as fd:
                     pymt_config.write(fd)
             except Exception, e:
-                pymt_logger.exception('Core: error while saving default configuration file')
+                pymt_logger.exception('Core: error while saving default'
+                                      'configuration file')
             pymt_logger.info('Core: PyMT configuration saved.')
             sys.exit(0)
 
@@ -196,8 +230,12 @@ if not 'PYMT_DOC_INCLUDE' in os.environ:
         if options['shadow_window']:
             pymt_logger.debug('Core: Creating PyMT Window')
             shadow_window = MTWindow()
+            pymt_configure()
 
     except getopt.GetoptError, err:
         pymt_logger.error('Core: %s' % str(err))
         pymt_usage()
         sys.exit(2)
+
+# cleanup namespace
+del sys, getopt, os
